@@ -7,8 +7,8 @@ from PIL import Image
 from IPython.display import display
 from dl2050utils.core import *
 from dl2050utils.fs import get_dir_files, get_dir_dirs
-from nn2.etc import *
-from nn2.tabular import DataFrameProcessor
+from dl2050nn.etc import *
+from dl2050nn.tabular import DataFrameProcessor
 
 # if regr:
 #     yrange = [df[c_dep].astype('float32').min(), df[c_dep].astype('float32').max()]
