@@ -3,11 +3,11 @@ import numpy as np
 import torch
 from IPython.display import display, clear_output
 from dl2050utils.core import listify, camel2snake
-from nn2.cbs import CancelBatchException, CancelEpochException, CancelTrainException, LR_Find, Recorder
-from nn2.optimizers import *
-from nn2.log import LoggerCallback
-from nn2.metrics import accuracy
-from nn2.etc import *
+from dl2050nn.cbs import CancelBatchException, CancelEpochException, CancelTrainException, LR_Find, Recorder
+from dl2050nn.optimizers import *
+from dl2050nn.log import LoggerCallback
+from dl2050nn.metrics import accuracy
+from dl2050nn.etc import *
 
 
 class Learner():
